sqlobject.tests.test_sqlbuilder_joins_instances module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_sqlbuilder_joins_instances module

class `sqlobject.tests.test_sqlbuilder_joins_instances.` `SBAddress`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addSBPerson`(obj)
  property `city`
  `j` = sb_address
  property `person`
  property `personID`
  `q` = sb_address
  `removeSBPerson`(obj)
  property `sharedPeople`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.SQLRelatedJoin object>]
    `joins` = [<sqlobject.joins.SOSQLRelatedJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_sqlbuilder_joins_instances.SBAddress`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'sb_address'

class `sqlobject.tests.test_sqlbuilder_joins_instances.` `SBPerson`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addSharedAddress`(obj)
  property `addresses`
  `j` = sb_person
  property `name`
  `q` = sb_person
  `removeSharedAddress`(obj)
  property `sharedAddresses`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.SQLMultipleJoin object>, <sqlobject.joins.SQLRelatedJoin object>]
    `joins` = [<sqlobject.joins.SOSQLRelatedJoin object>, <sqlobject.joins.SOSQLMultipleJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_sqlbuilder_joins_instances.SBPerson`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'sb_person'

`sqlobject.tests.test_sqlbuilder_joins_instances.` `setup_module`(mod)

`sqlobject.tests.test_sqlbuilder_joins_instances.` `testFK`()

`sqlobject.tests.test_sqlbuilder_joins_instances.` `testFK2`()

`sqlobject.tests.test_sqlbuilder_joins_instances.` `testInstance`()

`sqlobject.tests.test_sqlbuilder_joins_instances.` `testJoin`()

`sqlobject.tests.test_sqlbuilder_joins_instances.` `testJoin2`()

`sqlobject.tests.test_sqlbuilder_joins_instances.` `testRelatedJoin`()

`sqlobject.tests.test_sqlbuilder_joins_instances.` `testRelatedJoin2`()